pub struct SessionWindow<T> {
pub start: SystemTime,
pub end: SystemTime,
pub events: Vec<StreamEvent<T>>,
pub session_id: u64,
}Expand description
A closed session window containing all events that fell within the session.
Fields
start: SystemTimeWall-clock timestamp of the first event.
end: SystemTimeWall-clock timestamp of the last event.
events: Vec<StreamEvent<T>>All events belonging to this session, in arrival order.
session_id: u64Monotonically increasing session identifier (0-based).
Implementations
Sourceimpl<T> SessionWindow<T>
impl<T> SessionWindow<T>